## dbt-tests-adapter 1.16.0 - June 04, 2025

### Features

- Add BaseCatalogIntegrationValidation to support catalog integration testing ([#1134](https://github.com/dbt-labs/dbt-adapters/issues/1134))
